@@ -104,6 +104,8 @@ module Braintree
         _local_payment_reversed_sample_xml
       when Braintree::WebhookNotification::Kind::PaymentMethodCustomerDataUpdated
         _payment_method_customer_data_updated_sample_xml(id)
+      when Braintree::WebhookNotification::Kind::RefundFailed
+        _refund_failed_sample_xml(id)
       else
         _subscription_sample_xml(id)
       end
@@ -1094,8 +1096,11 @@ module Braintree
     def _local_payment_completed_sample_xml(id)
       <<-XML
         <local-payment>
-          <payment-id>PAY-XYZ123</payment-id>
+          <bic>BIC</bic>
+          <iban_last_chars>1234</iban_last_chars>
           <payer-id>ABCPAYER</payer-id>
+          <payer-name>PAYERNAME</payer-name>
+          <payment-id>PAY-XYZ123</payment-id>
           <payment-method-nonce>ee257d98-de40-47e8-96b3-a6954ea7a9a4</payment-method-nonce>
           <transaction>
             <id>#{id}</id>
@@ -1181,5 +1186,21 @@ module Braintree
         </venmo-account>
         XML
     end
+
+    def _refund_failed_sample_xml(id)
+      <<-XML
+        <transaction>
+          <id>#{id}</id>
+          <amount>100</amount>
+          <credit-card>
+            <number>1234560000001234</number>
+            <cvv>123</cvv>
+            <card-type>MasterCard</card-type>
+          </credit-card>
+          <status>processor_declined</status>
+          <refunded-transaction-id>1</refunded-transaction-id>
+        </transaction>
+      XML
+    end
   end
 end
